@@ -106,10 +106,50 @@ rsync -av $RSYNC_EXCLUDES ./ "$RELEASE_DIR/"
 # Ensure required directories exist in release
 mkdir -p "$RELEASE_DIR/sql/migrations"
 
-# Get list of all migration directories sorted by version
+# Handle staging migrations - move them to proper version folder
+if [ -d "sql/migrations/staging" ] && [ "$(ls -A sql/migrations/staging 2>/dev/null)" ]; then
+    echo -e "${YELLOW}Found staging migrations, organizing for version $VERSION${NC}"
+    
+    # Create version directory
+    mkdir -p "sql/migrations/$VERSION"
+    
+    # Move staging migrations to version folder  
+    mv sql/migrations/staging/* "sql/migrations/$VERSION/"
+    
+    # Remove empty staging directory
+    rmdir sql/migrations/staging 2>/dev/null || true
+    
+    echo "Staging migrations moved to sql/migrations/$VERSION/"
+    
+    # Commit the organized migrations back to git
+    if git status --porcelain | grep -q "sql/"; then
+        echo "Committing organized migrations to git..."
+        git add sql/
+        git commit -m "Organize staging migrations for release $VERSION
+
+- Move staging migrations to sql/migrations/$VERSION/
+- Update complete-database-setup.sql with new schema changes
+
+Auto-generated commit from build-release.sh
+
+🤖 Generated with [Claude Code](https://claude.ai/code)
+
+Co-Authored-By: Claude <noreply@anthropic.com>"
+        
+        # Push to remote if on a branch that tracks remote
+        if git rev-parse --abbrev-ref --symbolic-full-name @{u} >/dev/null 2>&1; then
+            echo "Pushing organized migrations to remote..."
+            git push
+        else
+            echo -e "${YELLOW}Note: Not pushing to remote (no upstream branch configured)${NC}"
+        fi
+    fi
+fi
+
+# Get list of all migration directories sorted by version (exclude staging)
 if [ -d "sql/migrations" ]; then
     cd "$PROJECT_ROOT/sql/migrations"
-    MIGRATIONS=($(ls -d */ 2>/dev/null | sed 's/\///' | sort -V))
+    MIGRATIONS=($(ls -d */ 2>/dev/null | sed 's/\///' | grep -v '^staging$' | sort -V))
     cd "$PROJECT_ROOT"
     
     TOTAL=${#MIGRATIONS[@]}
