@@ -267,8 +267,9 @@ function getUserInfo($userMgmt, $username) {
 
 function getUserResources($username) {
     try {
-        require_once(__DIR__ . '/../../libs/database.php');
-        $db = Database::getInstance()->getConnection();
+        require_once(__DIR__ . '/../../libs/mysqlmgmt.php');
+        $MySQLMgmt = new mysqlmgmt();
+        $db = $MySQLMgmt->getMySQLConnection();
         
         $stmt = $db->prepare("
             SELECT max_cpu_allowance, max_memory_allowance, max_disk_space, max_domains, 
@@ -307,8 +308,9 @@ function getUserResources($username) {
 
 function setUserResources($username, $resources) {
     try {
-        require_once(__DIR__ . '/../../libs/database.php');
-        $db = Database::getInstance()->getConnection();
+        require_once(__DIR__ . '/../../libs/mysqlmgmt.php');
+        $MySQLMgmt = new mysqlmgmt();
+        $db = $MySQLMgmt->getMySQLConnection();
         
         // Check if user already has resource limits
         $stmt = $db->prepare("SELECT id FROM client_allowances WHERE username = ?");
